
dialogId("odp-v-kachna", "font_big", "Doesn’t this duck look suspicious to you?")
dialogStr("Ziet dit eendje er niet een beetje verdacht uit?")


dialogId("odp-m-zda0", "font_small", "I think it looks dumb.")
dialogStr("Het ziet er stom uit.")


dialogId("odp-m-zda1", "font_small", "I think it looks inflatable.")
dialogStr("Het ziet er opblaasbaar uit.")


dialogId("odp-v-snehulak", "font_big", "Can you see that snowman?")
dialogStr("Zie je die sneeuwpop?")


dialogId("odp-m-blaznis", "font_small", "What do you mean? Snowmen belong to the Mess Hall.")
dialogStr("Hoe bedoel je? Sneeuwpoppen horen in de kajuit.")


dialogId("odp-m-kohout", "font_small", "Try to open that tap!")
dialogStr("Draai die kraan eens open!")


dialogId("odp-v-vtip", "font_big", "Now, this was a joke. Heh, heh.")
dialogStr("He, dat was een grapje.  Ha, ha.")


dialogId("odp-m-predmet", "font_small", "And there isn't even a funny animated object here.")
dialogStr("En hier is ook al geen lollig bewegend dingetje ofzo.")


dialogId("odp-v-pozadi", "font_big", "But a beautifully wavy background.")
dialogStr("Maar wel een prachtige golvende achtergrond.")


dialogId("odp-v-pohni", "font_big", "Move on, so that we can get going.")
dialogStr("Schiet op, dan kunnen we hier weg.")


dialogId("odp-v-coja", "font_big", "And what about me?")
dialogStr("En ik dan?")


dialogId("odp-v-nestacim", "font_big", "Am I not enough for you now, or what?")
dialogStr("Ben ik niet goed genoeg voor je, ofzo?")

